@@ -1,5 +1,5 @@
 use crate::application::ics20_fungible_token_transfer::context::Ics20Context;
-use crate::application::ics20_fungible_token_transfer::error::{Error, Kind};
+use crate::application::ics20_fungible_token_transfer::error::Error;
 use crate::application::ics20_fungible_token_transfer::msgs::transfer::MsgTransfer;
 use crate::handler::HandlerOutput;
 use crate::ics04_channel::handler::send_packet::send_packet;
@@ -16,7 +16,7 @@ where
     let source_channel_end = ctx
         .channel_end(&(msg.source_port.clone(), msg.source_channel.clone()))
         .ok_or_else(|| {
-            Kind::ChannelNotFound(msg.source_port.clone(), msg.source_channel.clone())
+            Error::channel_not_found(msg.source_port.clone(), msg.source_channel.clone())
         })?;
 
     let destination_port = source_channel_end.counterparty().port_id().clone();
@@ -24,14 +24,17 @@ where
         .counterparty()
         .channel_id()
         .ok_or_else(|| {
-            Kind::DestinationChannelNotFound(msg.source_port.clone(), msg.source_channel.clone())
+            Error::destination_channel_not_found(
+                msg.source_port.clone(),
+                msg.source_channel.clone(),
+            )
         })?;
 
     // get the next sequence
     let sequence = ctx
         .get_next_sequence_send(&(msg.source_port.clone(), msg.source_channel.clone()))
         .ok_or_else(|| {
-            Kind::SequenceSendNotFound(msg.source_port.clone(), msg.source_channel.clone())
+            Error::sequence_send_not_found(msg.source_port.clone(), msg.source_channel.clone())
         })?;
 
     //TODO: Application LOGIC.
@@ -47,8 +50,7 @@ where
         timeout_timestamp: msg.timeout_timestamp,
     };
 
-    let handler_output =
-        send_packet(ctx, packet).map_err(|e| Kind::HandlerRaisedError.context(e))?;
+    let handler_output = send_packet(ctx, packet).map_err(Error::ics04_channel)?;
 
     //TODO:  add event/atributes and writes to the store issued by the application logic for packet sending.
     Ok(handler_output)
