@@ -1,19 +1,67 @@
-use std::collections::HashMap;
-
-use anomaly::BoxError;
 use serde_derive::{Deserialize, Serialize};
 
+use crate::ics02_client::error as client_error;
 use crate::ics02_client::events as ClientEvents;
 use crate::ics02_client::events::NewBlock;
+use crate::ics02_client::height::HeightError;
 use crate::ics03_connection::events as ConnectionEvents;
 use crate::ics03_connection::events::Attributes as ConnectionAttributes;
+use crate::ics04_channel::error as channel_error;
 use crate::ics04_channel::events as ChannelEvents;
 use crate::ics04_channel::events::Attributes as ChannelAttributes;
-
+use crate::ics24_host::error::ValidationError;
+use crate::timestamp::ParseTimestampError;
 use crate::Height;
+use flex_error::{define_error, TraceError};
 use prost::alloc::fmt::Formatter;
 use std::fmt;
 
+define_error! {
+    Error {
+        Height
+            [ HeightError ]
+            | _ | { "error parsing height" },
+
+        Parse
+            [ ValidationError ]
+            | _ | { "parse error" },
+
+        Client
+            [ client_error::Error ]
+            | _ | { "ICS02 client error" },
+
+        Channel
+            [ channel_error::Error ]
+            | _ | { "channel error" },
+
+        Timestamp
+            [ ParseTimestampError ]
+            | _ | { "error parsing timestamp" },
+
+        MissingKey
+            { key: String }
+            | e | { format_args!("missing event key {}", e.key) },
+
+        Decode
+            [ TraceError<prost::DecodeError> ]
+            | _ | { "error decoding protobuf" },
+
+        SubtleEncoding
+            [ TraceError<subtle_encoding::Error> ]
+            | _ | { "error decoding hex" },
+
+        MissingActionString
+            | _ | { "Missing action string" },
+
+        IncorrectEventType
+            { event: String }
+            | e | {
+                format_args!("Incorrect Event Type {}",
+                    e.event)
+            },
+    }
+}
+
 /// Events types
 #[derive(Debug, Clone, Deserialize, Serialize)]
 pub enum IbcEventType {
@@ -209,78 +257,3 @@ impl IbcEvent {
         }
     }
 }
-
-#[derive(Debug, Clone, Deserialize, Serialize)]
-pub struct RawObject {
-    pub height: Height,
-    pub action: String,
-    pub idx: usize,
-    pub events: HashMap<String, Vec<String>>,
-}
-
-impl RawObject {
-    pub fn new(
-        height: Height,
-        action: String,
-        idx: usize,
-        events: HashMap<String, Vec<String>>,
-    ) -> RawObject {
-        RawObject {
-            height,
-            action,
-            idx,
-            events,
-        }
-    }
-}
-
-pub fn extract_events<S: ::std::hash::BuildHasher>(
-    events: &HashMap<String, Vec<String>, S>,
-    action_string: &str,
-) -> Result<(), BoxError> {
-    if let Some(message_action) = events.get("message.action") {
-        if message_action.contains(&action_string.to_owned()) {
-            return Ok(());
-        }
-        return Err("Missing action string".into());
-    }
-    Err("Incorrect Event Type".into())
-}
-
-#[macro_export]
-macro_rules! make_event {
-    ($a:ident, $b:literal) => {
-        #[derive(Debug, Deserialize, Serialize, Clone)]
-        pub struct $a {
-            pub data: ::std::collections::HashMap<String, Vec<String>>,
-        }
-        impl ::std::convert::TryFrom<$crate::events::RawObject> for $a {
-            type Error = ::anomaly::BoxError;
-
-            fn try_from(result: $crate::events::RawObject) -> Result<Self, Self::Error> {
-                match $crate::events::extract_events(&result.events, $b) {
-                    Ok(()) => Ok($a {
-                        data: result.events.clone(),
-                    }),
-                    Err(e) => Err(e),
-                }
-            }
-        }
-    };
-}
-
-#[macro_export]
-macro_rules! attribute {
-    ($a:ident, $b:literal) => {
-        $a.events.get($b).ok_or($b)?[$a.idx].parse()?
-    };
-}
-
-#[macro_export]
-macro_rules! some_attribute {
-    ($a:ident, $b:literal) => {
-        $a.events
-            .get($b)
-            .map_or_else(|| None, |tags| tags[$a.idx].parse().ok())
-    };
-}
