@@ -4,7 +4,7 @@ use crate::downcast;
 use crate::ics02_client::client_consensus::{AnyConsensusState, ConsensusState};
 use crate::ics02_client::client_state::{AnyClientState, ClientState};
 use crate::ics02_client::client_type::ClientType;
-use crate::ics02_client::error::Kind;
+use crate::ics02_client::error::Error;
 use crate::ics02_client::header::{AnyHeader, Header};
 use crate::ics03_connection::connection::ConnectionEnd;
 use crate::ics04_channel::channel::ChannelEnd;
@@ -27,7 +27,7 @@ pub trait ClientDef: Clone {
         &self,
         client_state: Self::ClientState,
         header: Self::Header,
-    ) -> Result<(Self::ClientState, Self::ConsensusState), Box<dyn std::error::Error>>;
+    ) -> Result<(Self::ClientState, Self::ConsensusState), Error>;
 
     fn verify_upgrade_and_update_state(
         &self,
@@ -35,7 +35,7 @@ pub trait ClientDef: Clone {
         consensus_state: &Self::ConsensusState,
         proof_upgrade_client: MerkleProof,
         proof_upgrade_consensus_state: MerkleProof,
-    ) -> Result<(Self::ClientState, Self::ConsensusState), Box<dyn std::error::Error>>;
+    ) -> Result<(Self::ClientState, Self::ConsensusState), Error>;
 
     /// Verification functions as specified in:
     /// <https://github.com/cosmos/ics/tree/master/spec/ics-002-client-semantics>
@@ -54,7 +54,7 @@ pub trait ClientDef: Clone {
         client_id: &ClientId,
         consensus_height: Height,
         expected_consensus_state: &AnyConsensusState,
-    ) -> Result<(), Box<dyn std::error::Error>>;
+    ) -> Result<(), Error>;
 
     /// Verify a `proof` that a connection state matches that of the input `connection_end`.
     fn verify_connection_state(
@@ -65,7 +65,7 @@ pub trait ClientDef: Clone {
         proof: &CommitmentProofBytes,
         connection_id: Option<&ConnectionId>,
         expected_connection_end: &ConnectionEnd,
-    ) -> Result<(), Box<dyn std::error::Error>>;
+    ) -> Result<(), Error>;
 
     /// Verify a `proof` that a channel state matches that of the input `channel_end`.
     #[allow(clippy::too_many_arguments)]
@@ -78,7 +78,7 @@ pub trait ClientDef: Clone {
         port_id: &PortId,
         channel_id: &ChannelId,
         expected_channel_end: &ChannelEnd,
-    ) -> Result<(), Box<dyn std::error::Error>>;
+    ) -> Result<(), Error>;
 
     /// Verify the client state for this chain that it is stored on the counterparty chain.
     #[allow(clippy::too_many_arguments)]
@@ -91,7 +91,7 @@ pub trait ClientDef: Clone {
         client_id: &ClientId,
         proof: &CommitmentProofBytes,
         client_state: &AnyClientState,
-    ) -> Result<(), Box<dyn std::error::Error>>;
+    ) -> Result<(), Error>;
 
     /// Verify a `proof` that a packet has been commited.
     #[allow(clippy::too_many_arguments)]
@@ -104,7 +104,7 @@ pub trait ClientDef: Clone {
         channel_id: &ChannelId,
         seq: &Sequence,
         commitment: String,
-    ) -> Result<(), Box<dyn std::error::Error>>;
+    ) -> Result<(), Error>;
 
     /// Verify a `proof` that a packet has been commited.
     #[allow(clippy::too_many_arguments)]
@@ -117,7 +117,7 @@ pub trait ClientDef: Clone {
         channel_id: &ChannelId,
         seq: &Sequence,
         ack: Vec<u8>,
-    ) -> Result<(), Box<dyn std::error::Error>>;
+    ) -> Result<(), Error>;
 
     /// Verify a `proof` that of the next_seq_received.
     #[allow(clippy::too_many_arguments)]
@@ -129,7 +129,7 @@ pub trait ClientDef: Clone {
         port_id: &PortId,
         channel_id: &ChannelId,
         seq: &Sequence,
-    ) -> Result<(), Box<dyn std::error::Error>>;
+    ) -> Result<(), Error>;
 
     /// Verify a `proof` that a packet has not been received.
     #[allow(clippy::too_many_arguments)]
@@ -141,7 +141,7 @@ pub trait ClientDef: Clone {
         port_id: &PortId,
         channel_id: &ChannelId,
         seq: &Sequence,
-    ) -> Result<(), Box<dyn std::error::Error>>;
+    ) -> Result<(), Error>;
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -174,14 +174,14 @@ impl ClientDef for AnyClient {
         &self,
         client_state: AnyClientState,
         header: AnyHeader,
-    ) -> Result<(AnyClientState, AnyConsensusState), Box<dyn std::error::Error>> {
+    ) -> Result<(AnyClientState, AnyConsensusState), Error> {
         match self {
             Self::Tendermint(client) => {
                 let (client_state, header) = downcast!(
                     client_state => AnyClientState::Tendermint,
                     header => AnyHeader::Tendermint,
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 let (new_state, new_consensus) =
                     client.check_header_and_update_state(client_state, header)?;
@@ -198,7 +198,7 @@ impl ClientDef for AnyClient {
                     client_state => AnyClientState::Mock,
                     header => AnyHeader::Mock,
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 let (new_state, new_consensus) =
                     client.check_header_and_update_state(client_state, header)?;
@@ -220,13 +220,13 @@ impl ClientDef for AnyClient {
         client_id: &ClientId,
         consensus_height: Height,
         expected_consensus_state: &AnyConsensusState,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         match self {
             Self::Tendermint(client) => {
                 let client_state = downcast!(
                     client_state => AnyClientState::Tendermint
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 client.verify_client_consensus_state(
                     client_state,
@@ -244,7 +244,7 @@ impl ClientDef for AnyClient {
                 let client_state = downcast!(
                     client_state => AnyClientState::Mock
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 client.verify_client_consensus_state(
                     client_state,
@@ -267,11 +267,11 @@ impl ClientDef for AnyClient {
         proof: &CommitmentProofBytes,
         connection_id: Option<&ConnectionId>,
         expected_connection_end: &ConnectionEnd,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         match self {
             Self::Tendermint(client) => {
                 let client_state = downcast!(client_state => AnyClientState::Tendermint)
-                    .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                    .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 client.verify_connection_state(
                     client_state,
@@ -286,7 +286,7 @@ impl ClientDef for AnyClient {
             #[cfg(any(test, feature = "mocks"))]
             Self::Mock(client) => {
                 let client_state = downcast!(client_state => AnyClientState::Mock)
-                    .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                    .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 client.verify_connection_state(
                     client_state,
@@ -309,11 +309,11 @@ impl ClientDef for AnyClient {
         port_id: &PortId,
         channel_id: &ChannelId,
         expected_channel_end: &ChannelEnd,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         match self {
             Self::Tendermint(client) => {
                 let client_state = downcast!(client_state => AnyClientState::Tendermint)
-                    .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                    .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 client.verify_channel_state(
                     client_state,
@@ -329,7 +329,7 @@ impl ClientDef for AnyClient {
             #[cfg(any(test, feature = "mocks"))]
             Self::Mock(client) => {
                 let client_state = downcast!(client_state => AnyClientState::Mock)
-                    .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                    .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 client.verify_channel_state(
                     client_state,
@@ -353,13 +353,13 @@ impl ClientDef for AnyClient {
         client_id: &ClientId,
         proof: &CommitmentProofBytes,
         client_state_on_counterparty: &AnyClientState,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         match self {
             Self::Tendermint(client) => {
                 let client_state = downcast!(
                     client_state => AnyClientState::Tendermint
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 client.verify_client_full_state(
                     client_state,
@@ -377,7 +377,7 @@ impl ClientDef for AnyClient {
                 let client_state = downcast!(
                     client_state => AnyClientState::Mock
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 client.verify_client_full_state(
                     client_state,
@@ -400,13 +400,13 @@ impl ClientDef for AnyClient {
         channel_id: &ChannelId,
         seq: &Sequence,
         commitment: String,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         match self {
             Self::Tendermint(client) => {
                 let client_state = downcast!(
                     client_state => AnyClientState::Tendermint
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 client.verify_packet_data(
                     client_state,
@@ -424,7 +424,7 @@ impl ClientDef for AnyClient {
                 let client_state = downcast!(
                     client_state => AnyClientState::Mock
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 client.verify_packet_data(
                     client_state,
@@ -448,13 +448,13 @@ impl ClientDef for AnyClient {
         channel_id: &ChannelId,
         seq: &Sequence,
         ack: Vec<u8>,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         match self {
             Self::Tendermint(client) => {
                 let client_state = downcast!(
                     client_state => AnyClientState::Tendermint
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 client.verify_packet_acknowledgement(
                     client_state,
@@ -472,7 +472,7 @@ impl ClientDef for AnyClient {
                 let client_state = downcast!(
                     client_state => AnyClientState::Mock
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 client.verify_packet_acknowledgement(
                     client_state,
@@ -495,13 +495,13 @@ impl ClientDef for AnyClient {
         port_id: &PortId,
         channel_id: &ChannelId,
         seq: &Sequence,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         match self {
             Self::Tendermint(client) => {
                 let client_state = downcast!(
                     client_state => AnyClientState::Tendermint
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 client.verify_next_sequence_recv(
                     client_state,
@@ -518,7 +518,7 @@ impl ClientDef for AnyClient {
                 let client_state = downcast!(
                     client_state => AnyClientState::Mock
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 client.verify_next_sequence_recv(
                     client_state,
@@ -539,13 +539,13 @@ impl ClientDef for AnyClient {
         port_id: &PortId,
         channel_id: &ChannelId,
         seq: &Sequence,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         match self {
             Self::Tendermint(client) => {
                 let client_state = downcast!(
                     client_state => AnyClientState::Tendermint
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 client.verify_packet_receipt_absence(
                     client_state,
@@ -562,7 +562,7 @@ impl ClientDef for AnyClient {
                 let client_state = downcast!(
                     client_state => AnyClientState::Mock
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 client.verify_packet_receipt_absence(
                     client_state,
@@ -582,14 +582,14 @@ impl ClientDef for AnyClient {
         consensus_state: &Self::ConsensusState,
         proof_upgrade_client: MerkleProof,
         proof_upgrade_consensus_state: MerkleProof,
-    ) -> Result<(Self::ClientState, Self::ConsensusState), Box<dyn std::error::Error>> {
+    ) -> Result<(Self::ClientState, Self::ConsensusState), Error> {
         match self {
             Self::Tendermint(client) => {
                 let (client_state, consensus_state) = downcast!(
                     client_state => AnyClientState::Tendermint,
                     consensus_state => AnyConsensusState::Tendermint,
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Tendermint))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Tendermint))?;
 
                 let (new_state, new_consensus) = client.verify_upgrade_and_update_state(
                     client_state,
@@ -610,7 +610,7 @@ impl ClientDef for AnyClient {
                     client_state => AnyClientState::Mock,
                     consensus_state => AnyConsensusState::Mock,
                 )
-                .ok_or_else(|| Kind::ClientArgsTypeMismatch(ClientType::Mock))?;
+                .ok_or_else(|| Error::client_args_type_mismatch(ClientType::Mock))?;
 
                 let (new_state, new_consensus) = client.verify_upgrade_and_update_state(
                     client_state,
