@@ -4,7 +4,7 @@ use crate::events::IbcEvent;
 use crate::handler::{HandlerOutput, HandlerResult};
 use crate::ics03_connection::connection::{ConnectionEnd, Counterparty, State};
 use crate::ics03_connection::context::ConnectionReader;
-use crate::ics03_connection::error::{Error, Kind};
+use crate::ics03_connection::error::Error;
 use crate::ics03_connection::events::Attributes;
 use crate::ics03_connection::handler::verify::verify_proofs;
 use crate::ics03_connection::handler::{ConnectionIdState, ConnectionResult};
@@ -22,18 +22,14 @@ pub(crate) fn process(
         Some(old_conn_end) => {
             if !(old_conn_end.state_matches(&State::TryOpen)) {
                 // Old connection end is in incorrect state, propagate the error.
-                Err(Into::<Error>::into(Kind::ConnectionMismatch(
-                    msg.connection_id().clone(),
-                )))
+                Err(Error::connection_mismatch(msg.connection_id().clone()))
             } else {
                 Ok(old_conn_end)
             }
         }
         None => {
             // No connection end exists for this conn. identifier. Impossible to continue handshake.
-            Err(Into::<Error>::into(Kind::UninitializedConnection(
-                msg.connection_id().clone(),
-            )))
+            Err(Error::uninitialized_connection(msg.connection_id().clone()))
         }
     }?;
 
