@@ -1,10 +1,10 @@
-use std::convert::{TryFrom, TryInto};
+use std::convert::TryFrom;
 
 use tendermint_proto::Protobuf;
 
 use ibc_proto::ibc::core::connection::v1::MsgConnectionOpenConfirm as RawMsgConnectionOpenConfirm;
 
-use crate::ics03_connection::error::{Error, Kind};
+use crate::ics03_connection::error::Error;
 use crate::ics24_host::identifier::ConnectionId;
 use crate::proofs::Proofs;
 use crate::signer::Signer;
@@ -50,21 +50,21 @@ impl Msg for MsgConnectionOpenConfirm {
 impl Protobuf<RawMsgConnectionOpenConfirm> for MsgConnectionOpenConfirm {}
 
 impl TryFrom<RawMsgConnectionOpenConfirm> for MsgConnectionOpenConfirm {
-    type Error = anomaly::Error<Kind>;
+    type Error = Error;
 
     fn try_from(msg: RawMsgConnectionOpenConfirm) -> Result<Self, Self::Error> {
         let proof_height = msg
             .proof_height
-            .ok_or(Kind::MissingProofHeight)?
-            .try_into() // Cast from the raw height type into the domain type.
-            .map_err(|e| Kind::InvalidProof.context(e))?;
+            .ok_or_else(Error::missing_proof_height)?
+            .into();
+
         Ok(Self {
             connection_id: msg
                 .connection_id
                 .parse()
-                .map_err(|e| Kind::IdentifierError.context(e))?,
+                .map_err(Error::invalid_identifier)?,
             proofs: Proofs::new(msg.proof_ack.into(), None, None, None, proof_height)
-                .map_err(|e| Kind::InvalidProof.context(e))?,
+                .map_err(Error::invalid_proof)?,
             signer: msg.signer.into(),
         })
     }
