@@ -5,7 +5,7 @@ use tendermint_proto::Protobuf;
 
 use ibc_proto::ibc::core::connection::v1::Version as RawVersion;
 
-use crate::ics03_connection::error::Kind;
+use crate::ics03_connection::error::Error;
 
 /// Stores the identifier and the features supported by a version
 #[derive(Clone, Debug, PartialEq, Eq, Hash, Serialize, Deserialize)]
@@ -26,18 +26,14 @@ impl Version {
 impl Protobuf<RawVersion> for Version {}
 
 impl TryFrom<RawVersion> for Version {
-    type Error = anomaly::Error<Kind>;
+    type Error = Error;
     fn try_from(value: RawVersion) -> Result<Self, Self::Error> {
         if value.identifier.trim().is_empty() {
-            return Err(Kind::InvalidVersion
-                .context("empty version string".to_string())
-                .into());
+            return Err(Error::empty_versions());
         }
         for feature in value.features.iter() {
             if feature.trim().is_empty() {
-                return Err(Kind::InvalidVersion
-                    .context("empty feature string".to_string())
-                    .into());
+                return Err(Error::empty_features());
             }
         }
         Ok(Version {
