@@ -4,7 +4,7 @@ use crate::handler::{HandlerOutput, HandlerResult};
 use crate::ics03_connection::connection::State as ConnectionState;
 use crate::ics04_channel::channel::{ChannelEnd, Counterparty, State};
 use crate::ics04_channel::context::ChannelReader;
-use crate::ics04_channel::error::{Error, Kind};
+use crate::ics04_channel::error::Error;
 use crate::ics04_channel::events::Attributes;
 use crate::ics04_channel::handler::verify::verify_channel_proofs;
 use crate::ics04_channel::handler::{ChannelIdState, ChannelResult};
@@ -19,11 +19,11 @@ pub(crate) fn process(
     // Retrieve the old channel end and validate it against the message.
     let mut channel_end = ctx
         .channel_end(&(msg.port_id().clone(), msg.channel_id().clone()))
-        .ok_or_else(|| Kind::ChannelNotFound(msg.port_id.clone(), msg.channel_id().clone()))?;
+        .ok_or_else(|| Error::channel_not_found(msg.port_id.clone(), msg.channel_id().clone()))?;
 
     // Validate that the channel end is in a state where it can be closed.
     if channel_end.state_matches(&State::Closed) {
-        return Err(Kind::ChannelClosed(msg.channel_id().clone()).into());
+        return Err(Error::channel_closed(msg.channel_id().clone()));
     }
 
     // Channel capabilities
@@ -31,15 +31,20 @@ pub(crate) fn process(
 
     // An OPEN IBC connection running on the local (host) chain should exist.
     if channel_end.connection_hops().len() != 1 {
-        return Err(
-            Kind::InvalidConnectionHopsLength(1, channel_end.connection_hops().len()).into(),
-        );
+        return Err(Error::invalid_connection_hops_length(
+            1,
+            channel_end.connection_hops().len(),
+        ));
     }
+
     let conn = ctx
         .connection_end(&channel_end.connection_hops()[0])
-        .ok_or_else(|| Kind::MissingConnection(channel_end.connection_hops()[0].clone()))?;
+        .ok_or_else(|| Error::missing_connection(channel_end.connection_hops()[0].clone()))?;
+
     if !conn.state_matches(&ConnectionState::Open) {
-        return Err(Kind::ConnectionNotOpen(channel_end.connection_hops()[0].clone()).into());
+        return Err(Error::connection_not_open(
+            channel_end.connection_hops()[0].clone(),
+        ));
     }
 
     // Proof verification in two steps:
@@ -50,7 +55,7 @@ pub(crate) fn process(
 
     let counterparty = conn.counterparty();
     let ccid = counterparty.connection_id().ok_or_else(|| {
-        Kind::UndefinedConnectionCounterparty(channel_end.connection_hops()[0].clone())
+        Error::undefined_connection_counterparty(channel_end.connection_hops()[0].clone())
     })?;
 
     let expected_connection_hops = vec![ccid.clone()];
@@ -69,8 +74,7 @@ pub(crate) fn process(
         &conn,
         &expected_channel_end,
         msg.proofs(),
-    )
-    .map_err(|e| Kind::FailedChanneOpenTryVerification.context(e))?;
+    )?;
 
     output.log("success: channel close confirm ");
 
