@@ -8,7 +8,7 @@ use crate::ics04_channel::handler::verify::{
 };
 use crate::ics04_channel::msgs::timeout::MsgTimeout;
 use crate::ics04_channel::packet::{PacketResult, Sequence};
-use crate::ics04_channel::{context::ChannelReader, error::Error, error::Kind};
+use crate::ics04_channel::{context::ChannelReader, error::Error};
 use crate::ics24_host::identifier::{ChannelId, PortId};
 use crate::timestamp::Expiry;
 
@@ -28,12 +28,11 @@ pub fn process(ctx: &dyn ChannelReader, msg: MsgTimeout) -> HandlerResult<Packet
     let mut source_channel_end = ctx
         .channel_end(&(packet.source_port.clone(), packet.source_channel.clone()))
         .ok_or_else(|| {
-            Kind::ChannelNotFound(packet.source_port.clone(), packet.source_channel.clone())
-                .context(packet.source_channel.to_string())
+            Error::channel_not_found(packet.source_port.clone(), packet.source_channel.clone())
         })?;
 
     if !source_channel_end.state_matches(&State::Open) {
-        return Err(Kind::ChannelClosed(packet.source_channel.clone()).into());
+        return Err(Error::channel_closed(packet.source_channel.clone()));
     }
 
     let _channel_cap = ctx.authenticated_capability(&packet.source_port)?;
@@ -44,16 +43,17 @@ pub fn process(ctx: &dyn ChannelReader, msg: MsgTimeout) -> HandlerResult<Packet
     );
 
     if !source_channel_end.counterparty_matches(&counterparty) {
-        return Err(Kind::InvalidPacketCounterparty(
+        return Err(Error::invalid_packet_counterparty(
             packet.destination_port.clone(),
             packet.destination_channel.clone(),
-        )
-        .into());
+        ));
     }
 
     let connection_end = ctx
         .connection_end(&source_channel_end.connection_hops()[0])
-        .ok_or_else(|| Kind::MissingConnection(source_channel_end.connection_hops()[0].clone()))?;
+        .ok_or_else(|| {
+            Error::missing_connection(source_channel_end.connection_hops()[0].clone())
+        })?;
 
     let client_id = connection_end.client_id().clone();
 
@@ -62,22 +62,24 @@ pub fn process(ctx: &dyn ChannelReader, msg: MsgTimeout) -> HandlerResult<Packet
     let packet_height = packet.timeout_height;
 
     if (!packet.timeout_height.is_zero()) && packet_height > proof_height {
-        return Err(
-            Kind::PacketTimeoutHeightNotReached(packet.timeout_height, proof_height).into(),
-        );
+        return Err(Error::packet_timeout_height_not_reached(
+            packet.timeout_height,
+            proof_height,
+        ));
     }
 
     let consensus_state = ctx
         .client_consensus_state(&client_id, proof_height)
-        .ok_or_else(|| Kind::MissingClientConsensusState(client_id.clone(), proof_height))?;
+        .ok_or_else(|| Error::missing_client_consensus_state(client_id.clone(), proof_height))?;
 
     let proof_timestamp = consensus_state.timestamp();
 
     let packet_timestamp = packet.timeout_timestamp;
     if let Expiry::Expired = packet_timestamp.check_expiry(&proof_timestamp) {
-        return Err(
-            Kind::PacketTimeoutTimestampNotReached(packet_timestamp, proof_timestamp).into(),
-        );
+        return Err(Error::packet_timeout_timestamp_not_reached(
+            packet_timestamp,
+            proof_timestamp,
+        ));
     }
 
     //verify packet commitment
@@ -87,7 +89,7 @@ pub fn process(ctx: &dyn ChannelReader, msg: MsgTimeout) -> HandlerResult<Packet
             packet.source_channel.clone(),
             packet.sequence,
         ))
-        .ok_or(Kind::PacketCommitmentNotFound(packet.sequence))?;
+        .ok_or_else(|| Error::packet_commitment_not_found(packet.sequence))?;
 
     let input = format!(
         "{:?},{:?},{:?}",
@@ -95,14 +97,15 @@ pub fn process(ctx: &dyn ChannelReader, msg: MsgTimeout) -> HandlerResult<Packet
     );
 
     if packet_commitment != ChannelReader::hash(ctx, input) {
-        return Err(Kind::IncorrectPacketCommitment(packet.sequence).into());
+        return Err(Error::incorrect_packet_commitment(packet.sequence));
     }
 
     let result = if source_channel_end.order_matches(&Order::Ordered) {
         if packet.sequence < msg.next_sequence_recv {
-            return Err(
-                Kind::InvalidPacketSequence(packet.sequence, msg.next_sequence_recv).into(),
-            );
+            return Err(Error::invalid_packet_sequence(
+                packet.sequence,
+                msg.next_sequence_recv,
+            ));
         }
         verify_next_sequence_recv(
             ctx,
