@@ -3,7 +3,7 @@ use crate::ics02_client::{client_def::AnyClient, client_def::ClientDef};
 use crate::ics03_connection::connection::ConnectionEnd;
 use crate::ics04_channel::channel::ChannelEnd;
 use crate::ics04_channel::context::ChannelReader;
-use crate::ics04_channel::error::{Error, Kind};
+use crate::ics04_channel::error::Error;
 use crate::ics04_channel::packet::{Packet, Sequence};
 use crate::ics24_host::identifier::ClientId;
 use crate::proofs::Proofs;
@@ -21,25 +21,28 @@ pub fn verify_channel_proofs(
 
     let client_state = ctx
         .client_state(&client_id)
-        .ok_or_else(|| Kind::MissingClientState(client_id.clone()))?;
+        .ok_or_else(|| Error::missing_client_state(client_id.clone()))?;
 
     // The client must not be frozen.
     if client_state.is_frozen() {
-        return Err(Kind::FrozenClient(client_id).into());
+        return Err(Error::frozen_client(client_id));
     }
 
     if ctx
         .client_consensus_state(&client_id, proofs.height())
         .is_none()
     {
-        return Err(Kind::MissingClientConsensusState(client_id, proofs.height()).into());
+        return Err(Error::missing_client_consensus_state(
+            client_id,
+            proofs.height(),
+        ));
     }
 
     let client_def = AnyClient::from_client_type(client_state.client_type());
 
     // Verify the proof for the channel state against the expected channel end.
     // A counterparty channel id of None in not possible, and is checked by validate_basic in msg.
-    Ok(client_def
+    client_def
         .verify_channel_state(
             &client_state,
             proofs.height(),
@@ -49,7 +52,7 @@ pub fn verify_channel_proofs(
             channel_end.counterparty().channel_id().unwrap(),
             expected_chan,
         )
-        .map_err(|_| Kind::InvalidProof)?)
+        .map_err(Error::verify_channel_failed)
 }
 
 /// Entry point for verifying all proofs bundled in a ICS4 packet recv. message.
@@ -61,18 +64,21 @@ pub fn verify_packet_recv_proofs(
 ) -> Result<(), Error> {
     let client_state = ctx
         .client_state(&client_id)
-        .ok_or_else(|| Kind::MissingClientState(client_id.clone()))?;
+        .ok_or_else(|| Error::missing_client_state(client_id.clone()))?;
 
     // The client must not be frozen.
     if client_state.is_frozen() {
-        return Err(Kind::FrozenClient(client_id).into());
+        return Err(Error::frozen_client(client_id));
     }
 
     if ctx
         .client_consensus_state(&client_id, proofs.height())
         .is_none()
     {
-        return Err(Kind::MissingClientConsensusState(client_id, proofs.height()).into());
+        return Err(Error::missing_client_consensus_state(
+            client_id,
+            proofs.height(),
+        ));
     }
 
     let client_def = AnyClient::from_client_type(client_state.client_type());
@@ -84,7 +90,7 @@ pub fn verify_packet_recv_proofs(
     let commitment = ctx.hash(input);
 
     // Verify the proof for the packet against the chain store.
-    Ok(client_def
+    client_def
         .verify_packet_data(
             &client_state,
             proofs.height(),
@@ -94,7 +100,9 @@ pub fn verify_packet_recv_proofs(
             &packet.sequence,
             commitment,
         )
-        .map_err(|_| Kind::PacketVerificationFailed(packet.sequence))?)
+        .map_err(|e| Error::packet_verification_failed(packet.sequence, e))?;
+
+    Ok(())
 }
 
 /// Entry point for verifying all proofs bundled in an ICS4 packet ack message.
@@ -107,17 +115,17 @@ pub fn verify_packet_acknowledgement_proofs(
 ) -> Result<(), Error> {
     let client_state = ctx
         .client_state(&client_id)
-        .ok_or_else(|| Kind::MissingClientState(client_id.clone()))?;
+        .ok_or_else(|| Error::missing_client_state(client_id.clone()))?;
 
     // The client must not be frozen.
     if client_state.is_frozen() {
-        return Err(Kind::FrozenClient(client_id).into());
+        return Err(Error::frozen_client(client_id));
     }
 
     let client_def = AnyClient::from_client_type(client_state.client_type());
 
     // Verify the proof for the packet against the chain store.
-    Ok(client_def
+    client_def
         .verify_packet_acknowledgement(
             &client_state,
             proofs.height(),
@@ -127,7 +135,9 @@ pub fn verify_packet_acknowledgement_proofs(
             &packet.sequence,
             acknowledgement,
         )
-        .map_err(|_| Kind::PacketVerificationFailed(packet.sequence))?)
+        .map_err(|e| Error::packet_verification_failed(packet.sequence, e))?;
+
+    Ok(())
 }
 
 /// Entry point for verifying all timeout proofs.
@@ -140,17 +150,17 @@ pub fn verify_next_sequence_recv(
 ) -> Result<(), Error> {
     let client_state = ctx
         .client_state(&client_id)
-        .ok_or_else(|| Kind::MissingClientState(client_id.clone()))?;
+        .ok_or_else(|| Error::missing_client_state(client_id.clone()))?;
 
     // The client must not be frozen.
     if client_state.is_frozen() {
-        return Err(Kind::FrozenClient(client_id).into());
+        return Err(Error::frozen_client(client_id));
     }
 
     let client_def = AnyClient::from_client_type(client_state.client_type());
 
     // Verify the proof for the packet against the chain store.
-    Ok(client_def
+    client_def
         .verify_next_sequence_recv(
             &client_state,
             proofs.height(),
@@ -159,7 +169,9 @@ pub fn verify_next_sequence_recv(
             &packet.destination_channel,
             &seq,
         )
-        .map_err(|_| Kind::PacketVerificationFailed(seq))?)
+        .map_err(|e| Error::packet_verification_failed(seq, e))?;
+
+    Ok(())
 }
 
 pub fn verify_packet_receipt_absence(
@@ -170,17 +182,17 @@ pub fn verify_packet_receipt_absence(
 ) -> Result<(), Error> {
     let client_state = ctx
         .client_state(&client_id)
-        .ok_or_else(|| Kind::MissingClientState(client_id.clone()))?;
+        .ok_or_else(|| Error::missing_client_state(client_id.clone()))?;
 
     // The client must not be frozen.
     if client_state.is_frozen() {
-        return Err(Kind::FrozenClient(client_id).into());
+        return Err(Error::frozen_client(client_id));
     }
 
     let client_def = AnyClient::from_client_type(client_state.client_type());
 
     // Verify the proof for the packet against the chain store.
-    Ok(client_def
+    client_def
         .verify_packet_receipt_absence(
             &client_state,
             proofs.height(),
@@ -189,5 +201,7 @@ pub fn verify_packet_receipt_absence(
             &packet.destination_channel,
             &packet.sequence,
         )
-        .map_err(|_| Kind::PacketVerificationFailed(packet.sequence))?)
+        .map_err(|e| Error::packet_verification_failed(packet.sequence, e))?;
+
+    Ok(())
 }
