@@ -4,7 +4,7 @@ use tendermint_proto::Protobuf;
 
 use ibc_proto::ibc::core::channel::v1::MsgAcknowledgement as RawMsgAcknowledgement;
 
-use crate::ics04_channel::error::{Error, Kind};
+use crate::ics04_channel::error::Error;
 use crate::ics04_channel::packet::Packet;
 use crate::proofs::Proofs;
 use crate::signer::Signer;
@@ -63,7 +63,7 @@ impl Msg for MsgAcknowledgement {
 impl Protobuf<RawMsgAcknowledgement> for MsgAcknowledgement {}
 
 impl TryFrom<RawMsgAcknowledgement> for MsgAcknowledgement {
-    type Error = anomaly::Error<Kind>;
+    type Error = Error;
 
     fn try_from(raw_msg: RawMsgAcknowledgement) -> Result<Self, Self::Error> {
         let proofs = Proofs::new(
@@ -73,18 +73,16 @@ impl TryFrom<RawMsgAcknowledgement> for MsgAcknowledgement {
             None,
             raw_msg
                 .proof_height
-                .ok_or(Kind::MissingHeight)?
-                .try_into()
-                .map_err(|e| Kind::InvalidProof.context(e))?,
+                .ok_or_else(Error::missing_height)?
+                .into(),
         )
-        .map_err(|e| Kind::InvalidProof.context(e))?;
+        .map_err(Error::invalid_proof)?;
 
         Ok(MsgAcknowledgement {
             packet: raw_msg
                 .packet
-                .ok_or(Kind::MissingPacket)?
-                .try_into()
-                .map_err(|e| Kind::InvalidPacket.context(e))?,
+                .ok_or_else(Error::missing_packet)?
+                .try_into()?,
             acknowledgement: raw_msg.acknowledgement,
             signer: raw_msg.signer.into(),
             proofs,
