@@ -1,5 +1,5 @@
 use crate::ics04_channel::channel::ChannelEnd;
-use crate::ics04_channel::error::{Error, Kind};
+use crate::ics04_channel::error::Error;
 use crate::ics24_host::identifier::PortId;
 use crate::signer::Signer;
 use crate::tx_msg::Msg;
@@ -57,15 +57,15 @@ impl Msg for MsgChannelOpenInit {
 impl Protobuf<RawMsgChannelOpenInit> for MsgChannelOpenInit {}
 
 impl TryFrom<RawMsgChannelOpenInit> for MsgChannelOpenInit {
-    type Error = anomaly::Error<Kind>;
+    type Error = Error;
 
     fn try_from(raw_msg: RawMsgChannelOpenInit) -> Result<Self, Self::Error> {
         Ok(MsgChannelOpenInit {
-            port_id: raw_msg
-                .port_id
-                .parse()
-                .map_err(|e| Kind::IdentifierError.context(e))?,
-            channel: raw_msg.channel.ok_or(Kind::MissingChannel)?.try_into()?,
+            port_id: raw_msg.port_id.parse().map_err(Error::identifier)?,
+            channel: raw_msg
+                .channel
+                .ok_or_else(Error::missing_channel)?
+                .try_into()?,
             signer: raw_msg.signer.into(),
         })
     }
