@@ -3,6 +3,7 @@ use ibc_proto::ibc::core::commitment::v1::MerkleProof;
 use crate::ics02_client::client_consensus::AnyConsensusState;
 use crate::ics02_client::client_def::ClientDef;
 use crate::ics02_client::client_state::AnyClientState;
+use crate::ics02_client::error::Error;
 use crate::ics03_connection::connection::ConnectionEnd;
 use crate::ics04_channel::channel::ChannelEnd;
 use crate::ics04_channel::packet::Sequence;
@@ -26,12 +27,12 @@ impl ClientDef for TendermintClient {
         &self,
         client_state: Self::ClientState,
         header: Self::Header,
-    ) -> Result<(Self::ClientState, Self::ConsensusState), Box<dyn std::error::Error>> {
+    ) -> Result<(Self::ClientState, Self::ConsensusState), Error> {
         if client_state.latest_height() >= header.height() {
-            return Err(
-                format!("received header height ({:?}) is lower than (or equal to) client latest height ({:?})",
-                    header.height(), client_state.latest_height).into(),
-            );
+            return Err(Error::low_header_height(
+                header.height(),
+                client_state.latest_height(),
+            ));
         }
 
         // TODO: Additional verifications should be implemented here.
@@ -51,7 +52,7 @@ impl ClientDef for TendermintClient {
         _client_id: &ClientId,
         _consensus_height: Height,
         _expected_consensus_state: &AnyConsensusState,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         todo!()
     }
 
@@ -63,7 +64,7 @@ impl ClientDef for TendermintClient {
         _proof: &CommitmentProofBytes,
         _connection_id: Option<&ConnectionId>,
         _expected_connection_end: &ConnectionEnd,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         todo!()
     }
 
@@ -76,7 +77,7 @@ impl ClientDef for TendermintClient {
         _port_id: &PortId,
         _channel_id: &ChannelId,
         _expected_channel_end: &ChannelEnd,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         todo!()
     }
 
@@ -89,7 +90,7 @@ impl ClientDef for TendermintClient {
         _client_id: &ClientId,
         _proof: &CommitmentProofBytes,
         _expected_client_state: &AnyClientState,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         unimplemented!()
     }
 
@@ -102,7 +103,7 @@ impl ClientDef for TendermintClient {
         _channel_id: &ChannelId,
         _seq: &Sequence,
         _data: String,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         todo!()
     }
 
@@ -115,7 +116,7 @@ impl ClientDef for TendermintClient {
         _channel_id: &ChannelId,
         _seq: &Sequence,
         _data: Vec<u8>,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         todo!()
     }
 
@@ -127,7 +128,7 @@ impl ClientDef for TendermintClient {
         _port_id: &PortId,
         _channel_id: &ChannelId,
         _seq: &Sequence,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         todo!()
     }
 
@@ -139,7 +140,7 @@ impl ClientDef for TendermintClient {
         _port_id: &PortId,
         _channel_id: &ChannelId,
         _seq: &Sequence,
-    ) -> Result<(), Box<dyn std::error::Error>> {
+    ) -> Result<(), Error> {
         todo!()
     }
 
@@ -149,7 +150,7 @@ impl ClientDef for TendermintClient {
         _consensus_state: &Self::ConsensusState,
         _proof_upgrade_client: MerkleProof,
         _proof_upgrade_consensus_state: MerkleProof,
-    ) -> Result<(Self::ClientState, Self::ConsensusState), Box<dyn std::error::Error>> {
+    ) -> Result<(Self::ClientState, Self::ConsensusState), Error> {
         todo!()
     }
 }
