@@ -43,13 +43,20 @@ impl From<Vec<u8>> for CommitmentRoot {
 #[derive(Clone, Debug, PartialEq)]
 pub struct CommitmentPath;
 
-#[derive(Clone, Debug, PartialEq, Eq, Serialize)]
+#[derive(Clone, PartialEq, Eq, Serialize)]
 #[serde(transparent)]
 pub struct CommitmentProofBytes {
     #[serde(serialize_with = "crate::serializers::ser_hex_upper")]
     bytes: Vec<u8>,
 }
 
+impl fmt::Debug for CommitmentProofBytes {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        let hex = Hex::upper_case().encode_to_string(&self.bytes).unwrap();
+        f.debug_tuple("CommitmentProof").field(&hex).finish()
+    }
+}
+
 impl CommitmentProofBytes {
     pub fn is_empty(&self) -> bool {
         self.bytes.len() == 0
@@ -89,7 +96,7 @@ impl TryFrom<CommitmentProofBytes> for RawMerkleProof {
     fn try_from(value: CommitmentProofBytes) -> Result<Self, Self::Error> {
         let value: Vec<u8> = value.into();
         let res: RawMerkleProof =
-            prost::Message::decode(value.as_ref()).map_err(Error::InvalidRawMerkleProof)?;
+            prost::Message::decode(value.as_ref()).map_err(Error::invalid_raw_merkle_proof)?;
         Ok(res)
     }
 }
