@@ -1,11 +1,4 @@
-use super::error::{ValidationError, ValidationKind};
-
-/// Bails from the current function with the given error kind.
-macro_rules! bail {
-    ($kind:expr) => {
-        return Err($kind.into());
-    };
-}
+use super::error::ValidationError as Error;
 
 /// Path separator (ie. forward slash '/')
 const PATH_SEPARATOR: char = '/';
@@ -15,27 +8,22 @@ const VALID_SPECIAL_CHARS: &str = "._+-#[]<>";
 ///
 /// A valid identifier only contain lowercase alphabetic characters, and be of a given min and max
 /// length.
-pub fn validate_identifier(id: &str, min: usize, max: usize) -> Result<(), ValidationError> {
+pub fn validate_identifier(id: &str, min: usize, max: usize) -> Result<(), Error> {
     assert!(max >= min);
 
     // Check identifier is not empty
     if id.is_empty() {
-        bail!(ValidationKind::empty());
+        return Err(Error::empty());
     }
 
     // Check identifier does not contain path separators
     if id.contains(PATH_SEPARATOR) {
-        bail!(ValidationKind::contains_separator(id.to_string()));
+        return Err(Error::contain_separator(id.to_string()));
     }
 
     // Check identifier length is between given min/max
     if id.len() < min || id.len() > max {
-        bail!(ValidationKind::invalid_length(
-            id.to_string(),
-            id.len(),
-            min,
-            max
-        ));
+        return Err(Error::invalid_length(id.to_string(), id.len(), min, max));
     }
 
     // Check that the identifier comprises only valid characters:
@@ -46,7 +34,7 @@ pub fn validate_identifier(id: &str, min: usize, max: usize) -> Result<(), Valid
         .chars()
         .all(|c| c.is_alphanumeric() || VALID_SPECIAL_CHARS.contains(c))
     {
-        bail!(ValidationKind::invalid_character(id.to_string()));
+        return Err(Error::invalid_character(id.to_string()));
     }
 
     // All good!
@@ -57,7 +45,7 @@ pub fn validate_identifier(id: &str, min: usize, max: usize) -> Result<(), Valid
 ///
 /// A valid identifier must be between 9-64 characters and only contain lowercase
 /// alphabetic characters,
-pub fn validate_client_identifier(id: &str) -> Result<(), ValidationError> {
+pub fn validate_client_identifier(id: &str) -> Result<(), Error> {
     validate_identifier(id, 9, 64)
 }
 
@@ -65,7 +53,7 @@ pub fn validate_client_identifier(id: &str) -> Result<(), ValidationError> {
 ///
 /// A valid Identifier must be between 10-64 characters and only contain lowercase
 /// alphabetic characters,
-pub fn validate_connection_identifier(id: &str) -> Result<(), ValidationError> {
+pub fn validate_connection_identifier(id: &str) -> Result<(), Error> {
     validate_identifier(id, 10, 64)
 }
 
@@ -73,7 +61,7 @@ pub fn validate_connection_identifier(id: &str) -> Result<(), ValidationError> {
 ///
 /// A valid Identifier must be between 2-64 characters and only contain lowercase
 /// alphabetic characters,
-pub fn validate_port_identifier(id: &str) -> Result<(), ValidationError> {
+pub fn validate_port_identifier(id: &str) -> Result<(), Error> {
     validate_identifier(id, 2, 64)
 }
 
@@ -81,7 +69,7 @@ pub fn validate_port_identifier(id: &str) -> Result<(), ValidationError> {
 ///
 /// A valid Identifier must be between 10-64 characters and only contain lowercase
 /// alphabetic characters,
-pub fn validate_channel_identifier(id: &str) -> Result<(), ValidationError> {
+pub fn validate_channel_identifier(id: &str) -> Result<(), Error> {
     validate_identifier(id, 8, 64)
 }
 
